==> haskell-hackage-db-2.1.3-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-db.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-7jrWptTByTzDq4MUFjMWkk
key:                  hackage-db-2.1.3-7jrWptTByTzDq4MUFjMWkk
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  32e26fbe06c54093a1a3314b88afbb1b
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-7jrWptTByTzDq4MUFjMWkk
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-2ooOAwlErgbHj6Tyvuh2I5 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    tar-0.5.1.1-6keqWeJls24DtCTnnceMw8 time-1.12.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-db-2.1.3-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-db.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-Chrz1WRusP0H7lzlhk422D
key:                  hackage-db-2.1.3-Chrz1WRusP0H7lzlhk422D
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  2986ca832884e04c5284b64e0f4aeb11
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-Chrz1WRusP0H7lzlhk422D
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-F9MXb1A8ug6GkYytoGh4jA base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    tar-0.5.1.1-HjkjPnYqDqc9KkBJn3FmUe time-1.12.2
    utf8-string-1.0.2-4puy9i6JhHg6bynwSjfiUA

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
